@@ -580,11 +580,14 @@ def driver(vars):
 
   message("Done.")
 
+# gunzip <fastq>.gz file, written to <fastq>
+
 def uncompress(filename):
-   outfil = open(filename[0:-3], "w+")
+   newfname = filename[0:-3]
+   outfil = open(newfname, "wb+")
    for line in gzip.open(filename):
       outfil.write(line)
-   return filename[0:-3]
+   return newfname
 
 def extract_reads(vars):
     message("extracting reads...")
